[Libreoffice-commits] core.git: basctl/source compilerplugins/clang include/sfx2 include/svx sc/source sd/Library_sd.mk sd/source sfx2/source slideshow/source svgio/inc svgio/source svx/source

Noel Grandin (via logerrit) logerrit at kemper.freedesktop.org
Fri Jun 14 09:38:41 UTC 2019


 basctl/source/basicide/basobj2.cxx                                  |    7 
 basctl/source/basicide/macrodlg.cxx                                 |    3 
 basctl/source/basicide/moduldlg.cxx                                 |    4 
 basctl/source/basicide/moduldlg.hxx                                 |    3 
 compilerplugins/clang/test/unusedfields.cxx                         |   23 
 compilerplugins/clang/unusedfields.cxx                              |   57 +
 compilerplugins/clang/unusedfields.only-used-in-constructor.results |   14 
 compilerplugins/clang/unusedfields.readonly.results                 |    8 
 compilerplugins/clang/unusedfields.untouched.results                |   14 
 compilerplugins/clang/unusedfields.writeonly.results                |  346 +++++-----
 include/sfx2/basedlgs.hxx                                           |    2 
 include/svx/dlgctl3d.hxx                                            |    1 
 include/svx/ruler.hxx                                               |    3 
 sc/source/filter/excel/frmbase.cxx                                  |    8 
 sc/source/filter/inc/formel.hxx                                     |    4 
 sc/source/filter/qpro/qproform.cxx                                  |    2 
 sc/source/filter/xml/XMLChangeTrackingExportHelper.cxx              |    1 
 sc/source/filter/xml/XMLChangeTrackingExportHelper.hxx              |    3 
 sc/source/ui/inc/tabvwsh.hxx                                        |    1 
 sc/source/ui/view/tabvwsh4.cxx                                      |    2 
 sd/Library_sd.mk                                                    |    1 
 sd/source/ui/slidesorter/controller/SlideSorterController.cxx       |    2 
 sd/source/ui/slidesorter/inc/view/SlsFontProvider.hxx               |   70 --
 sd/source/ui/slidesorter/view/SlsFontProvider.cxx                   |   82 --
 sd/source/ui/slidesorter/view/SlsPageObjectLayouter.cxx             |    1 
 sfx2/source/dialog/basedlgs.cxx                                     |    5 
 slideshow/source/engine/animatedsprite.cxx                          |    2 
 slideshow/source/inc/animatedsprite.hxx                             |    1 
 svgio/inc/svgsymbolnode.hxx                                         |    6 
 svgio/source/svgreader/svgsymbolnode.cxx                            |    7 
 svx/source/dialog/dlgctl3d.cxx                                      |   15 
 svx/source/dialog/rlrcitem.cxx                                      |    2 
 svx/source/dialog/svxruler.cxx                                      |    6 
 33 files changed, 277 insertions(+), 429 deletions(-)

New commits:
commit 8303e7ed668fbcbd0ba75bd9dd259f03073ffd46
Author:     Noel Grandin <noel.grandin at collabora.co.uk>
AuthorDate: Fri Jun 14 10:41:11 2019 +0200
Commit:     Noel Grandin <noel.grandin at collabora.co.uk>
CommitDate: Fri Jun 14 11:37:35 2019 +0200

    loplugin:unusedfields improvements
    
    tighten up the only calling write-only methods part of the analysis
    
    Change-Id: I5bc6fdf0ce51940653317e8a48c5241705c90d4c
    Reviewed-on: https://gerrit.libreoffice.org/74022
    Tested-by: Jenkins
    Reviewed-by: Noel Grandin <noel.grandin at collabora.co.uk>

diff --git a/basctl/source/basicide/basobj2.cxx b/basctl/source/basicide/basobj2.cxx
index 380107c4e1ce..1f627d0fd7ec 100644
--- a/basctl/source/basicide/basobj2.cxx
+++ b/basctl/source/basicide/basobj2.cxx
@@ -67,12 +67,7 @@ void Organize(weld::Window* pParent, sal_Int16 tabId)
 {
     EnsureIde();
 
-    EntryDescriptor aDesc;
-    if (Shell* pShell = GetShell())
-        if (BaseWindow* pCurWin = pShell->GetCurWindow())
-            aDesc = pCurWin->CreateEntryDescriptor();
-
-    auto xDlg(std::make_shared<OrganizeDialog>(pParent, tabId, aDesc));
+    auto xDlg(std::make_shared<OrganizeDialog>(pParent, tabId));
     weld::DialogController::runAsync(xDlg, [](int) {});
 }
 
diff --git a/basctl/source/basicide/macrodlg.cxx b/basctl/source/basicide/macrodlg.cxx
index 41a99a51307e..3f7585decefe 100644
--- a/basctl/source/basicide/macrodlg.cxx
+++ b/basctl/source/basicide/macrodlg.cxx
@@ -744,8 +744,7 @@ IMPL_LINK(MacroChooser, ButtonHdl, weld::Button&, rButton, void)
         StoreMacroDescription();
 
         m_xBasicBox->get_selected(m_xBasicBoxIter.get());
-        EntryDescriptor aDesc = m_xBasicBox->GetEntryDescriptor(m_xBasicBoxIter.get());
-        auto xDlg(std::make_shared<OrganizeDialog>(m_xDialog.get(), 0, aDesc));
+        auto xDlg(std::make_shared<OrganizeDialog>(m_xDialog.get(), 0));
         weld::DialogController::runAsync(xDlg, [this](sal_Int32 nRet) {
             if (nRet == RET_OK) // not only closed
             {
diff --git a/basctl/source/basicide/moduldlg.cxx b/basctl/source/basicide/moduldlg.cxx
index 11f4946a7fde..1c113f7d9d35 100644
--- a/basctl/source/basicide/moduldlg.cxx
+++ b/basctl/source/basicide/moduldlg.cxx
@@ -181,14 +181,12 @@ void Shell::CopyDialogResources(
 }
 
 // OrganizeDialog
-OrganizeDialog::OrganizeDialog(weld::Window* pParent, sal_Int16 tabId,
-    EntryDescriptor const & rDesc )
+OrganizeDialog::OrganizeDialog(weld::Window* pParent, sal_Int16 tabId )
     : GenericDialogController(pParent, "modules/BasicIDE/ui/organizedialog.ui", "OrganizeDialog")
     , m_xTabCtrl(m_xBuilder->weld_notebook("tabcontrol"))
     , m_xModulePage(new ObjectPage(m_xTabCtrl->get_page("modules"), "ModulePage", BrowseMode::Modules, this))
     , m_xDialogPage(new ObjectPage(m_xTabCtrl->get_page("dialogs"), "DialogPage", BrowseMode::Dialogs, this))
     , m_xLibPage(new LibPage(m_xTabCtrl->get_page("libraries"), this))
-    , m_aCurEntry(rDesc)
 {
     m_xTabCtrl->connect_enter_page(LINK(this, OrganizeDialog, ActivatePageHdl));
 
diff --git a/basctl/source/basicide/moduldlg.hxx b/basctl/source/basicide/moduldlg.hxx
index 60633dd280ac..99a425a2b032 100644
--- a/basctl/source/basicide/moduldlg.hxx
+++ b/basctl/source/basicide/moduldlg.hxx
@@ -201,12 +201,11 @@ private:
     std::unique_ptr<ObjectPage> m_xModulePage;
     std::unique_ptr<ObjectPage> m_xDialogPage;
     std::unique_ptr<LibPage> m_xLibPage;
-    EntryDescriptor    m_aCurEntry;
 
     DECL_LINK(ActivatePageHdl, const OString&, void);
 
 public:
-    OrganizeDialog(weld::Window* pParent, sal_Int16 tabId, EntryDescriptor const & rDesc);
+    OrganizeDialog(weld::Window* pParent, sal_Int16 tabId);
     virtual ~OrganizeDialog() override;
 };
 
diff --git a/compilerplugins/clang/test/unusedfields.cxx b/compilerplugins/clang/test/unusedfields.cxx
index 6b4c64623c52..2ec4ab815414 100644
--- a/compilerplugins/clang/test/unusedfields.cxx
+++ b/compilerplugins/clang/test/unusedfields.cxx
@@ -198,11 +198,11 @@ struct ReadOnlyAnalysis3
 // add elements.
 struct ReadOnlyAnalysis4
 // expected-error at -1 {{read m_readonly [loplugin:unusedfields]}}
-// expected-error at -2 {{write m_readwrite [loplugin:unusedfields]}}
+// expected-error at -2 {{write m_writeonly [loplugin:unusedfields]}}
 // expected-error at -3 {{read m_readonlyCss [loplugin:unusedfields]}}
 {
     std::vector<int> m_readonly;
-    std::vector<int> m_readwrite;
+    std::vector<int> m_writeonly;
     css::uno::Sequence<sal_Int32> m_readonlyCss;
 
     void func1()
@@ -211,7 +211,8 @@ struct ReadOnlyAnalysis4
         (void)x;
         *m_readonly.begin() = 1;
 
-        m_readwrite.push_back(0);
+        m_writeonly.push_back(0);
+        m_writeonly.clear();
 
         x = m_readonlyCss.getArray()[0];
     }
@@ -241,6 +242,22 @@ struct WriteOnlyAnalysis2
     }
 };
 
+namespace WriteOnlyAnalysis3
+{
+    void setFoo(int);
+    struct Foo1
+    // expected-error at -1 {{read m_field1 [loplugin:unusedfields]}}
+    // expected-error at -2 {{write m_field1 [loplugin:unusedfields]}}
+    {
+        int m_field1;
+        Foo1() : m_field1(1) {}
+        ~Foo1()
+        {
+            setFoo(m_field1);
+        }
+    };
+};
+
 #endif
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab cinoptions=b1,g0,N-s cinkeys+=0=break: */
diff --git a/compilerplugins/clang/unusedfields.only-used-in-constructor.results b/compilerplugins/clang/unusedfields.only-used-in-constructor.results
index a864ee8779c0..8229f7f54cc2 100644
--- a/compilerplugins/clang/unusedfields.only-used-in-constructor.results
+++ b/compilerplugins/clang/unusedfields.only-used-in-constructor.results
@@ -14,6 +14,8 @@ avmedia/source/vlc/wrapper/Types.hxx:47
     libvlc_event_t u union (anonymous union at /media/noel/disk2/libo5/avmedia/source/vlc/wrapper/Types.hxx:41:5)
 avmedia/source/vlc/wrapper/Types.hxx:53
     libvlc_track_description_t psz_name char *
+basctl/source/basicide/moduldlg.hxx:204
+    basctl::OrganizeDialog m_aCurEntry class basctl::EntryDescriptor
 basegfx/source/polygon/b2dtrapezoid.cxx:202
     basegfx::trapezoidhelper::PointBlockAllocator maFirstStackBlock class basegfx::B2DPoint [32]
 basic/qa/cppunit/basictest.hxx:27
@@ -353,7 +355,7 @@ include/vcl/commandevent.hxx:315
 include/vcl/font/Feature.hxx:102
     vcl::font::Feature m_eType const enum vcl::font::FeatureType
 include/vcl/svimpbox.hxx:127
-    SvImpLBox aFctSet class ImpLBSelEng
+    SvImpLBox m_aFctSet class ImpLBSelEng
 include/xmloff/shapeimport.hxx:140
     SdXML3DLightContext mbSpecular _Bool
 libreofficekit/qa/gtktiledviewer/gtv-application-window.cxx:35
@@ -728,7 +730,7 @@ sw/inc/unosett.hxx:145
     SwXNumberingRules m_pImpl ::sw::UnoImplPtr<Impl>
 sw/qa/core/test_ToxTextGenerator.cxx:139
     ToxTextGeneratorWithMockedChapterField mChapterFieldType class SwChapterFieldType
-sw/qa/extras/layout/layout.cxx:2583
+sw/qa/extras/layout/layout.cxx:2608
       class SvtSysLocaleOptions &
 sw/qa/extras/uiwriter/uiwriter.cxx:4078
     IdleTask maIdle class Idle
@@ -772,9 +774,9 @@ ucb/source/ucp/gio/gio_mount.hxx:80
     OOoMountOperationClass _gtk_reserved4 void (*)(void)
 vcl/headless/svpgdi.cxx:311
     (anonymous namespace)::SourceHelper aTmpBmp class SvpSalBitmap
-vcl/inc/canvasbitmap.hxx:44
+vcl/inc/canvasbitmap.hxx:42
     vcl::unotools::VclCanvasBitmap m_aAlpha ::Bitmap
-vcl/inc/graphic/Manager.hxx:44
+vcl/inc/graphic/Manager.hxx:40
     vcl::graphic::Manager maSwapOutTimer class Timer
 vcl/inc/opengl/RenderList.hxx:29
     Vertex color glm::vec4
@@ -788,8 +790,6 @@ vcl/inc/qt5/Qt5FilePicker.hxx:83
     Qt5FilePicker m_pFilterLabel class QLabel *
 vcl/inc/qt5/Qt5Graphics.hxx:61
     Qt5Graphics m_lastPopupRect class QRect
-vcl/inc/qt5/Qt5Object.hxx:39
-    Qt5Object m_pParent class Qt5Frame *
 vcl/inc/salmenu.hxx:42
     SalMenuButtonItem mnId sal_uInt16
 vcl/inc/salmenu.hxx:43
@@ -822,7 +822,7 @@ vcl/inc/WidgetThemeLibrary.hxx:106
     vcl::WidgetThemeLibrary_t nSize uint32_t
 vcl/source/app/salvtables.cxx:2430
     SalInstanceEntry m_aTextFilter class (anonymous namespace)::WeldTextFilter
-vcl/source/app/salvtables.cxx:4834
+vcl/source/app/salvtables.cxx:4861
     SalInstanceComboBoxWithEdit m_aTextFilter class (anonymous namespace)::WeldTextFilter
 vcl/source/gdi/jobset.cxx:36
     ImplOldJobSetupData cDeviceName char [32]
diff --git a/compilerplugins/clang/unusedfields.readonly.results b/compilerplugins/clang/unusedfields.readonly.results
index 10b53fd582d8..dd0a2d0dd11e 100644
--- a/compilerplugins/clang/unusedfields.readonly.results
+++ b/compilerplugins/clang/unusedfields.readonly.results
@@ -354,6 +354,8 @@ include/svtools/editsyntaxhighlighter.hxx:32
     MultiLineEditSyntaxHighlight m_aColorConfig const svtools::ColorConfig
 include/svx/dialcontrol.hxx:112
     svx::DialControl::DialControl_Impl mnLinkedFieldValueMultiplyer sal_Int32
+include/svx/dlgctl3d.hxx:250
+    SvxLightCtl3D maUserInteractiveChangeCallback Link<class SvxLightCtl3D *, void>
 include/svx/graphctl.hxx:53
     GraphCtrl xVD ScopedVclPtrInstance<class VirtualDevice>
 include/svx/sdr/overlay/overlayanimatedbitmapex.hxx:51
@@ -708,7 +710,7 @@ unotools/source/config/saveopt.cxx:76
     SvtSaveOptions_Impl bROUserAutoSave _Bool
 vcl/inc/BitmapFastScaleFilter.hxx:31
     BitmapFastScaleFilter maSize const class Size
-vcl/inc/printerinfomanager.hxx:75
+vcl/inc/printerinfomanager.hxx:74
     psp::PrinterInfoManager::SystemPrintQueue m_aComment class rtl::OUString
 vcl/inc/salwtype.hxx:157
     SalWheelMouseEvent mbDeltaIsPixel _Bool
@@ -722,9 +724,9 @@ vcl/inc/svdata.hxx:286
     ImplSVNWFData mbMenuBarDockingAreaCommonBG _Bool
 vcl/inc/toolbox.h:108
     vcl::ToolBoxLayoutData m_aLineItemIds std::vector<sal_uInt16>
-vcl/inc/unx/i18n_status.hxx:56
+vcl/inc/unx/i18n_status.hxx:54
     vcl::I18NStatus m_aCurrentIM const class rtl::OUString
-vcl/inc/unx/saldisp.hxx:285
+vcl/inc/unx/saldisp.hxx:282
     SalDisplay m_aInvalidScreenData const struct SalDisplay::ScreenData
 vcl/inc/WidgetThemeLibrary.hxx:21
     vcl::WidgetDrawStyle maFaceColor uint32_t
diff --git a/compilerplugins/clang/unusedfields.untouched.results b/compilerplugins/clang/unusedfields.untouched.results
index 4e6656711762..1f7b11f268f3 100644
--- a/compilerplugins/clang/unusedfields.untouched.results
+++ b/compilerplugins/clang/unusedfields.untouched.results
@@ -10,6 +10,10 @@ avmedia/source/vlc/wrapper/Types.hxx:47
     libvlc_event_t u union (anonymous union at /media/noel/disk2/libo5/avmedia/source/vlc/wrapper/Types.hxx:41:5)
 avmedia/source/vlc/wrapper/Types.hxx:53
     libvlc_track_description_t psz_name char *
+basctl/source/basicide/moduldlg.hxx:113
+    basctl::OrganizePage m_xContainer std::unique_ptr<weld::Container>
+basctl/source/basicide/moduldlg.hxx:204
+    basctl::OrganizeDialog m_aCurEntry class basctl::EntryDescriptor
 basctl/source/inc/dlged.hxx:122
     basctl::DlgEditor pObjFac std::unique_ptr<DlgEdFactory, o3tl::default_delete<DlgEdFactory> >
 basic/qa/cppunit/basictest.hxx:27
@@ -160,11 +164,11 @@ include/oox/vml/vmlshapecontext.hxx:116
     oox::vml::ShapeTypeContext m_pShapeType std::shared_ptr<ShapeType>
 include/registry/registry.hxx:35
     Registry_Api acquire void (*)(RegHandle)
-include/sfx2/dinfdlg.hxx:478
+include/sfx2/dinfdlg.hxx:477
     CmisValue m_xFrame std::unique_ptr<weld::Frame>
-include/sfx2/dinfdlg.hxx:487
+include/sfx2/dinfdlg.hxx:486
     CmisDateTime m_xFrame std::unique_ptr<weld::Frame>
-include/sfx2/dinfdlg.hxx:497
+include/sfx2/dinfdlg.hxx:496
     CmisYesNo m_xFrame std::unique_ptr<weld::Frame>
 include/sfx2/mgetempl.hxx:63
     SfxManageStyleSheetPage m_xNameFt std::unique_ptr<weld::Label>
@@ -556,7 +560,7 @@ sdext/source/pdfimport/pdfparse/pdfparse.cxx:263
     PDFGrammar::definition value rule<ScannerT>
 sfx2/inc/autoredactdialog.hxx:105
     SfxAutoRedactDialog m_xDocShell class SfxObjectShellLock
-sfx2/inc/autoredactdialog.hxx:109
+sfx2/inc/autoredactdialog.hxx:110
     SfxAutoRedactDialog m_xRedactionTargetsLabel std::unique_ptr<weld::Label>
 sfx2/source/doc/doctempl.cxx:117
     DocTempl::DocTempl_EntryData_Impl mxObjShell const class SfxObjectShellLock
@@ -626,7 +630,7 @@ svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.hxx:154
     textconversiondlgs::ChineseDictionaryDialog m_xFT_Mapping std::unique_ptr<weld::Label>
 svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.hxx:157
     textconversiondlgs::ChineseDictionaryDialog m_xFT_Property std::unique_ptr<weld::Label>
-sw/qa/extras/layout/layout.cxx:2583
+sw/qa/extras/layout/layout.cxx:2608
       class SvtSysLocaleOptions &
 sw/source/core/crsr/crbm.cxx:66
     (anonymous namespace)::CursorStateHelper m_aSaveState const class SwCursorSaveState
diff --git a/compilerplugins/clang/unusedfields.writeonly.results b/compilerplugins/clang/unusedfields.writeonly.results
index 585dd492763e..2934b1906b33 100644
--- a/compilerplugins/clang/unusedfields.writeonly.results
+++ b/compilerplugins/clang/unusedfields.writeonly.results
@@ -1,3 +1,5 @@
+basctl/source/basicide/moduldlg.hxx:131
+    basctl::ObjectPage m_xDropTarget std::unique_ptr<SbTreeListBoxDropTarget>
 basctl/source/inc/basidesh.hxx:87
     basctl::Shell m_aNotifier class basctl::DocumentEventNotifier
 basctl/source/inc/bastype2.hxx:183
@@ -56,6 +58,8 @@ bridges/source/jni_uno/jni_java2uno.cxx:151
     jni_uno::largest p void *
 bridges/source/jni_uno/jni_java2uno.cxx:152
     jni_uno::largest a uno_Any
+canvas/source/cairo/cairo_canvasbitmap.hxx:122
+    cairocanvas::CanvasBitmap mpBufferCairo ::cairo::CairoSharedPtr
 canvas/source/cairo/cairo_spritedevicehelper.hxx:77
     cairocanvas::SpriteDeviceHelper mbFullScreen _Bool
 canvas/source/cairo/cairo_spritehelper.hxx:103
@@ -70,6 +74,10 @@ chart2/source/controller/dialogs/DialogModel.cxx:173
     (anonymous namespace)::lcl_DataSeriesContainerAppend m_rDestCnt (anonymous namespace)::lcl_DataSeriesContainerAppend::tContainerType *
 chart2/source/controller/dialogs/DialogModel.cxx:232
     (anonymous namespace)::lcl_RolesWithRangeAppend m_rDestCnt (anonymous namespace)::lcl_RolesWithRangeAppend::tContainerType *
+chart2/source/controller/inc/ChartController.hxx:417
+    chart::ChartController m_apDropTargetHelper std::unique_ptr<DropTargetHelper>
+chart2/source/controller/inc/dlg_View3D.hxx:51
+    chart::View3DDialog m_xIllumination std::unique_ptr<ThreeD_SceneIllumination_TabPage>
 chart2/source/controller/main/ElementSelector.hxx:38
     chart::ListBoxEntryData nHierarchyDepth sal_Int32
 chart2/source/inc/MediaDescriptorHelper.hxx:71
@@ -84,12 +92,10 @@ codemaker/source/javamaker/classfile.cxx:540
      doubleBytes double
 comphelper/qa/container/comphelper_ifcontainer.cxx:42
     ContainerListener m_pStats struct ContainerStats *const
-configmgr/source/components.cxx:84
-    configmgr::(anonymous namespace)::UnresolvedVectorItem name class rtl::OUString
+comphelper/source/misc/asyncnotification.cxx:80
+    comphelper::EventNotifierImpl pKeepThisAlive std::shared_ptr<AsyncEventNotifierAutoJoin>
 configmgr/source/components.cxx:163
     configmgr::Components::WriteThread reference_ rtl::Reference<WriteThread> *
-connectivity/source/cpool/ZConnectionPool.hxx:101
-    connectivity::(anonymous) xPooledConnection css::uno::Reference<css::sdbc::XPooledConnection>
 connectivity/source/drivers/mork/MorkParser.hxx:133
     MorkParser error_ enum MorkErrors
 connectivity/source/drivers/postgresql/pq_statics.hxx:106
@@ -126,10 +132,8 @@ connectivity/source/drivers/postgresql/pq_statics.hxx:192
     pq_sdbc_driver::Statics KEY_COLUMN class rtl::OUString
 connectivity/source/drivers/postgresql/pq_statics.hxx:216
     pq_sdbc_driver::Statics HELP_TEXT class rtl::OUString
-connectivity/source/inc/dbase/DTable.hxx:62
-    connectivity::dbase::ODbaseTable::DBFHeader dateElems sal_uInt8 [3]
-connectivity/source/inc/dbase/DTable.hxx:86
-    connectivity::dbase::ODbaseTable::DBFColumn db_adr sal_uInt32
+connectivity/source/inc/calc/CConnection.hxx:54
+    connectivity::calc::OCalcConnection::CloseVetoButTerminateListener m_pCloseListener std::unique_ptr<utl::CloseVeto>
 connectivity/source/inc/odbc/OConnection.hxx:57
     connectivity::odbc::OConnection m_sUser class rtl::OUString
 connectivity/source/inc/odbc/ODatabaseMetaDataResultSet.hxx:72
@@ -144,20 +148,8 @@ connectivity/source/inc/OTypeInfo.hxx:36
     connectivity::OTypeInfo nMaximumScale sal_Int16
 connectivity/source/inc/OTypeInfo.hxx:38
     connectivity::OTypeInfo nType sal_Int16
-connectivity/source/parse/sqliterator.cxx:118
-    connectivity::ForbidQueryName m_sForbiddenQueryName class rtl::OUString
-cppcanvas/source/inc/implrenderer.hxx:92
-    cppcanvas::internal::XForm eM11 float
-cppcanvas/source/inc/implrenderer.hxx:93
-    cppcanvas::internal::XForm eM12 float
-cppcanvas/source/inc/implrenderer.hxx:94
-    cppcanvas::internal::XForm eM21 float
-cppcanvas/source/inc/implrenderer.hxx:95
-    cppcanvas::internal::XForm eM22 float
-cppcanvas/source/inc/implrenderer.hxx:96
-    cppcanvas::internal::XForm eDx float
-cppcanvas/source/inc/implrenderer.hxx:97
-    cppcanvas::internal::XForm eDy float
+connectivity/source/inc/writer/WConnection.hxx:66
+    connectivity::writer::OWriterConnection::CloseVetoButTerminateListener m_pCloseListener std::unique_ptr<utl::CloseVeto>
 cppcanvas/source/inc/implrenderer.hxx:215
     cppcanvas::internal::ImplRenderer aBaseTransform struct cppcanvas::internal::XForm
 cppu/source/typelib/typelib.cxx:897
@@ -212,12 +204,62 @@ cppuhelper/source/access_control.cxx:80
     cppu::(anonymous namespace)::permission m_str2 rtl_uString *
 cppuhelper/source/typemanager.cxx:825
     (anonymous namespace)::BaseOffset set_ std::set<OUString>
+cui/source/inc/backgrnd.hxx:132
+    SvxBackgroundTabPage m_xBackgroundColorSetWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/backgrnd.hxx:133
+    SvxBackgroundTabPage m_xPreviewWin1 std::unique_ptr<weld::CustomWeld>
+cui/source/inc/border.hxx:133
+    SvxBorderTabPage m_xWndPresetsWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/border.hxx:154
+    SvxBorderTabPage m_xWndShadowsWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/chardlg.hxx:39
+    SvxCharBasePage m_xPreviewWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/connect.hxx:52
+    SvxConnectionPage m_xCtlPreview std::unique_ptr<weld::CustomWeld>
 cui/source/inc/cuihyperdlg.hxx:57
     SvxHlinkCtrl aRdOnlyForwarder class SfxStatusForwarder
 cui/source/inc/cuihyperdlg.hxx:77
     SvxHpLinkDlg maCtrl class SvxHlinkCtrl
-cui/source/tabpages/swpossizetabpage.cxx:616
-    (anonymous namespace)::FrmMaps pMap const struct FrmMap *
+cui/source/inc/cuitabarea.hxx:326
+    SvxShadowTabPage m_xCtlXRectPreview std::unique_ptr<weld::CustomWeld>
+cui/source/inc/cuitabarea.hxx:392
+    SvxGradientTabPage m_xGradientLBWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/cuitabarea.hxx:612
+    SvxPatternTabPage m_xCtlPixelWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/cuitabarea.hxx:614
+    SvxPatternTabPage m_xPatternLBWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/cuitabarea.hxx:714
+    SvxColorTabPage m_xValSetColorListWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/cuitabarea.hxx:715
+    SvxColorTabPage m_xValSetRecentListWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/cuitabline.hxx:150
+    SvxLineTabPage m_xCtlPreview std::unique_ptr<weld::CustomWeld>
+cui/source/inc/cuitabline.hxx:271
+    SvxLineDefTabPage m_xCtlPreview std::unique_ptr<weld::CustomWeld>
+cui/source/inc/cuitabline.hxx:347
+    SvxLineEndDefTabPage m_xCtlPreview std::unique_ptr<weld::CustomWeld>
+cui/source/inc/grfpage.hxx:87
+    SvxGrfCropPage m_xExampleWN std::unique_ptr<weld::CustomWeld>
+cui/source/inc/measure.hxx:56
+    SvxMeasurePage m_xCtlPosition std::unique_ptr<weld::CustomWeld>
+cui/source/inc/measure.hxx:57
+    SvxMeasurePage m_xCtlPreview std::unique_ptr<weld::CustomWeld>
+cui/source/inc/numfmt.hxx:122
+    SvxNumberFormatTabPage m_xWndPreview std::unique_ptr<weld::CustomWeld>
+cui/source/inc/numpages.hxx:74
+    SvxSingleNumPickTabPage m_xExamplesVSWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/numpages.hxx:108
+    SvxBulletPickTabPage m_xExamplesVSWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/numpages.hxx:149
+    SvxNumPickTabPage m_xExamplesVSWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/numpages.hxx:191
+    SvxBitmapPickTabPage m_xExamplesVSWin std::unique_ptr<weld::CustomWeld>
+cui/source/inc/numpages.hxx:273
+    SvxNumOptionsTabPage m_xPreviewWIN std::unique_ptr<weld::CustomWeld>
+cui/source/inc/numpages.hxx:369
+    SvxNumPositionTabPage m_xPreviewWIN std::unique_ptr<weld::CustomWeld>
+cui/source/inc/screenshotannotationdlg.hxx:30
+    ScreenshotAnnotationDlg m_pImpl std::unique_ptr<ScreenshotAnnotationDlg_Impl>
 dbaccess/source/core/dataaccess/databasedocument.hxx:176
     dbaccess::ODatabaseDocument m_pEventExecutor ::rtl::Reference<DocumentEventExecutor>
 dbaccess/source/core/dataaccess/documentdefinition.cxx:287
@@ -228,16 +270,18 @@ dbaccess/source/core/inc/SingleSelectQueryComposer.hxx:86
     dbaccess::OSingleSelectQueryComposer m_aTablesCollection std::vector<std::unique_ptr<OPrivateTables> >
 dbaccess/source/core/inc/TableDeco.hxx:67
     dbaccess::ODBTableDecorator m_xColumnMediator css::uno::Reference<css::container::XContainerListener>
-dbaccess/source/core/misc/DatabaseDataProvider.cxx:621
-    dbaccess::(anonymous namespace)::ColumnDescription nResultSetPosition sal_Int32
-dbaccess/source/core/misc/DatabaseDataProvider.cxx:622
-    dbaccess::(anonymous namespace)::ColumnDescription nDataType sal_Int32
 dbaccess/source/filter/xml/dbloader2.cxx:227
     dbaxml::DBContentLoader m_xMySelf Reference<class com::sun::star::frame::XFrameLoader>
 dbaccess/source/ui/browser/dbloader.cxx:69
     DBContentLoader m_xListener Reference<class com::sun::star::frame::XLoadEventListener>
+dbaccess/source/ui/inc/RelationController.hxx:33
+    dbaui::ORelationController m_pWaitObject std::unique_ptr<WaitObject>
 desktop/qa/desktop_lib/test_desktop_lib.cxx:216
     DesktopLOKTest m_bModified _Bool
+desktop/source/app/app.cxx:1229
+    desktop::ExecuteGlobals pLanguageOptions std::unique_ptr<SvtLanguageOptions>
+desktop/source/app/app.cxx:1230
+    desktop::ExecuteGlobals pPathOptions std::unique_ptr<SvtPathOptions>
 desktop/source/deployment/gui/dp_gui_updatedialog.hxx:152
     dp_gui::UpdateDialog m_xExtensionManager css::uno::Reference<css::deployment::XExtensionManager>
 desktop/source/deployment/gui/dp_gui_updateinstalldialog.cxx:117
@@ -264,8 +308,6 @@ drawinglayer/source/attribute/sdrfillgraphicattribute.cxx:47
     drawinglayer::attribute::ImpSdrFillGraphicAttribute mbLogSize _Bool
 drawinglayer/source/attribute/sdrsceneattribute3d.cxx:32
     drawinglayer::attribute::ImpSdrSceneAttribute mfDistance double
-drawinglayer/source/tools/emfpbrush.hxx:103
-    emfplushelper::EMFPBrush wrapMode sal_Int32
 drawinglayer/source/tools/emfpcustomlinecap.hxx:34
     emfplushelper::EMFPCustomLineCap mbIsFilled _Bool
 embeddedobj/source/inc/oleembobj.hxx:136
@@ -286,34 +328,24 @@ embeddedobj/source/inc/oleembobj.hxx:179
     OleEmbeddedObject m_nStatusAspect sal_Int64
 embeddedobj/source/inc/oleembobj.hxx:193
     OleEmbeddedObject m_bFromClipboard _Bool
-emfio/inc/mtftools.hxx:120
-    emfio::LOGFONTW lfOrientation sal_Int32
-emfio/inc/mtftools.hxx:126
-    emfio::LOGFONTW lfOutPrecision sal_uInt8
-emfio/inc/mtftools.hxx:127
-    emfio::LOGFONTW lfClipPrecision sal_uInt8
-emfio/inc/mtftools.hxx:128
-    emfio::LOGFONTW lfQuality sal_uInt8
 emfio/inc/mtftools.hxx:513
     emfio::MtfTools mrclBounds tools::Rectangle
-emfio/source/reader/emfreader.cxx:311
-    (anonymous namespace)::BLENDFUNCTION aBlendOperation unsigned char
-emfio/source/reader/emfreader.cxx:312
-    (anonymous namespace)::BLENDFUNCTION aBlendFlags unsigned char
 extensions/source/propctrlr/genericpropertyhandler.hxx:63
     pcr::GenericPropertyHandler m_xComponentIntrospectionAccess css::uno::Reference<css::beans::XIntrospectionAccess>
 extensions/source/scanner/scanner.hxx:45
     ScannerManager mpData void *
 framework/inc/services/layoutmanager.hxx:259
     framework::LayoutManager m_bGlobalSettings _Bool
+framework/inc/services/layoutmanager.hxx:273
+    framework::LayoutManager m_pGlobalSettings std::unique_ptr<GlobalSettings>
 framework/inc/uielement/langselectionmenucontroller.hxx:81
     framework::LanguageSelectionMenuController m_xMenuDispatch_Lang css::uno::Reference<css::frame::XDispatch>
 framework/inc/uielement/langselectionmenucontroller.hxx:83
     framework::LanguageSelectionMenuController m_xMenuDispatch_Font css::uno::Reference<css::frame::XDispatch>
 framework/inc/uielement/langselectionmenucontroller.hxx:85
     framework::LanguageSelectionMenuController m_xMenuDispatch_CharDlgForParagraph css::uno::Reference<css::frame::XDispatch>
-framework/source/fwe/classes/addonsoptions.cxx:222
-    framework::AddonsOptions_Impl::OneImageEntry aURL class rtl::OUString
+framework/source/layoutmanager/toolbarlayoutmanager.hxx:280
+    framework::ToolbarLayoutManager m_pGlobalSettings std::unique_ptr<GlobalSettings>
 framework/source/layoutmanager/toolbarlayoutmanager.hxx:284
     framework::ToolbarLayoutManager m_bGlobalSettings _Bool
 i18nutil/source/utility/paper.cxx:301
@@ -376,6 +408,10 @@ include/opencl/platforminfo.hxx:30
     OpenCLDeviceInfo mnComputeUnits size_t
 include/opencl/platforminfo.hxx:31
     OpenCLDeviceInfo mnFrequency size_t
+include/sfx2/basedlgs.hxx:46
+    SfxModalDialog pOutputSet std::unique_ptr<SfxItemSet>
+include/sfx2/basedlgs.hxx:69
+    SfxModelessDialog aSize class Size
 include/sfx2/minfitem.hxx:35
     SfxMacroInfoItem aCommentText const class rtl::OUString
 include/sfx2/notebookbar/NotebookbarTabControl.hxx:44
@@ -390,12 +426,20 @@ include/svtools/ctrltool.hxx:150
     FontList mpDev2 VclPtr<class OutputDevice>
 include/svx/bmpmask.hxx:128
     SvxBmpMask aSelItem class SvxBmpMaskSelectItem
-include/svx/ClassificationDialog.hxx:38
-    svx::ClassificationDialog m_aInitialValues std::vector<ClassificationResult>
+include/svx/float3d.hxx:171
+    Svx3DWin pControllerItem std::unique_ptr<Svx3DCtrlItem>
 include/svx/fmtools.hxx:134
     FmXDisposeListener m_pAdapter rtl::Reference<FmXDisposeMultiplexer>
+include/svx/gridctrl.hxx:255
+    DbGridControl m_pCursorDisposeListener std::unique_ptr<DisposeListenerGridBridge>
 include/svx/ofaitem.hxx:44
     OfaRefItem mxRef rtl::Reference<reference_type>
+include/svx/ruler.hxx:94
+    SvxRuler mxParaBorderItem std::unique_ptr<SvxLRSpaceItem>
+include/svx/srchdlg.hxx:161
+    SvxSearchDialog pSearchController std::unique_ptr<SvxSearchController>
+include/svx/srchdlg.hxx:162
+    SvxSearchDialog pOptionsController std::unique_ptr<SvxSearchController>
 include/svx/viewpt3d.hxx:62
     Viewport3D::(anonymous) X double
 include/svx/viewpt3d.hxx:62
@@ -406,8 +450,6 @@ include/test/beans/xpropertyset.hxx:56
     apitest::XPropertySet::PropsToTest constrained std::vector<OUString>
 include/unotools/fontcfg.hxx:158
     utl::FontSubstConfiguration maSubstHash utl::FontSubstConfiguration::UniqueSubstHash
-include/vcl/builder.hxx:123
-    VclBuilder m_aDeferredProperties VclBuilder::stringmap
 include/vcl/opengl/OpenGLContext.hxx:32
     GLWindow bMultiSampleSupported _Bool
 include/vcl/salnativewidgets.hxx:443
@@ -418,8 +460,6 @@ include/vcl/salnativewidgets.hxx:509
     PushButtonValue mbSingleLine _Bool
 include/vcl/textrectinfo.hxx:32
     TextRectInfo mnLineCount sal_uInt16
-include/vcl/toolbox.hxx:112
-    ToolBox mnKeyModifier sal_uInt16
 include/vcl/vclenum.hxx:199
     ItalicMatrix yy double
 include/vcl/vclenum.hxx:199
@@ -434,8 +474,6 @@ include/xmloff/shapeimport.hxx:181
     SdXML3DSceneAttributesHelper mbVPNUsed _Bool
 include/xmloff/shapeimport.hxx:182
     SdXML3DSceneAttributesHelper mbVUPUsed _Bool
-include/xmlreader/xmlreader.hxx:93
-    xmlreader::XmlReader::ElementData inheritedNamespaces const NamespaceList::size_type
 io/source/stm/odata.cxx:240
     io_stm::ODataInputStream::readDouble()::(anonymous union)::(anonymous) n2 sal_uInt32
 io/source/stm/odata.cxx:240
@@ -462,18 +500,8 @@ registry/source/reflread.cxx:465
     ConstantPool::readDoubleConstant(sal_uInt16)::(anonymous union)::(anonymous) b1 sal_uInt32
 registry/source/reflread.cxx:466
     ConstantPool::readDoubleConstant(sal_uInt16)::(anonymous union)::(anonymous) b2 sal_uInt32
-registry/source/reflread.cxx:533
-    FieldList m_pCP class ConstantPool *const
-registry/source/reflread.cxx:717
-    ReferenceList m_pCP class ConstantPool *const
-registry/source/reflread.cxx:818
-    MethodList m_pCP class ConstantPool *const
 reportdesign/inc/RptObject.hxx:72
     rptui::OObjectBase m_xKeepShapeAlive css::uno::Reference<css::uno::XInterface>
-sal/qa/osl/file/osl_File.cxx:2426
-    osl_File::setPos nCount_read sal_uInt64
-sal/qa/osl/file/osl_File.cxx:2898
-    osl_File::write nCount_read sal_uInt64
 sal/qa/osl/file/osl_File.cxx:4156
     osl_Directory::isOpen nError1 osl::class FileBase::RC
 sal/qa/osl/file/osl_File.cxx:4156
@@ -502,8 +530,6 @@ sal/textenc/tcvtutf7.cxx:396
     ImplUTF7FromUCContextData mnBitBuffer sal_uInt32
 sal/textenc/tcvtutf7.cxx:397
     ImplUTF7FromUCContextData mnBufferBits sal_uInt32
-sc/inc/columnspanset.hxx:57
-    sc::ColumnSpanSet::ColumnType miPos ColumnSpansType::const_iterator
 sc/inc/compiler.hxx:256
     ScCompiler::AddInMap pODFF const char *
 sc/inc/compiler.hxx:257
@@ -512,46 +538,24 @@ sc/inc/compiler.hxx:259
     ScCompiler::AddInMap pUpper const char *
 sc/inc/document.hxx:2582
     ScMutationDisable mpDocument class ScDocument *
-sc/inc/matrixoperators.hxx:22
-    sc::op::Op_ mInitVal const double
-sc/inc/orcusxml.hxx:35
-    ScOrcusXMLTreeParam::EntryData mnNamespaceID size_t
 sc/inc/pivot.hxx:75
     ScDPLabelData mnFlags sal_Int32
 sc/inc/pivot.hxx:78
     ScDPLabelData mbIsValue _Bool
 sc/inc/scmatrix.hxx:118
     ScMatrix mbCloneIfConst _Bool
+sc/inc/scmod.hxx:102
+    ScModule m_pErrorHdl std::unique_ptr<SfxErrorHandler>
 sc/inc/tabopparams.hxx:38
     ScInterpreterTableOpParams bValid _Bool
-sc/source/core/data/cellvalues.cxx:24
-    sc::(anonymous namespace)::BlockPos mnEnd size_t
-sc/source/core/data/column2.cxx:3175
-    (anonymous namespace)::FindUsedRowsHandler miUsed UsedRowsType::const_iterator
 sc/source/core/data/column4.cxx:1308
     (anonymous namespace)::StartListeningFormulaCellsHandler mnStartRow SCROW
 sc/source/core/data/column.cxx:1397
     (anonymous namespace)::CopyByCloneHandler meListenType sc::StartListeningType
 sc/source/core/data/column.cxx:1398
     (anonymous namespace)::CopyByCloneHandler mnFormulaCellCloneFlags const enum ScCloneFlags
-sc/source/core/data/sortparam.cxx:264
-    sc::(anonymous namespace)::ReorderIndex mnPos1 SCCOLROW
 sc/source/core/data/table2.cxx:3590
     (anonymous namespace)::OutlineArrayFinder mpArray class ScOutlineArray *
-sc/source/core/data/table2.cxx:3591
-    (anonymous namespace)::OutlineArrayFinder mbSizeChanged _Bool
-sc/source/core/data/table3.cxx:237
-    ScSortInfoArray::Cell maDrawObjects std::vector<SdrObject *>
-sc/source/core/data/table3.cxx:538
-    (anonymous namespace)::SortedColumn miPatternPos PatRangeType::const_iterator
-sc/source/core/data/table3.cxx:564
-    (anonymous namespace)::SortedRowFlags miPosHidden FlagsType::const_iterator
-sc/source/core/data/table3.cxx:565
-    (anonymous namespace)::SortedRowFlags miPosFiltered FlagsType::const_iterator
-sc/source/core/inc/bcaslot.hxx:289
-    ScBroadcastAreaSlotMachine aBulkBroadcastAreas ScBroadcastAreasBulk
-sc/source/filter/excel/xltoolbar.hxx:24
-    TBCCmd cmdID sal_uInt16
 sc/source/filter/excel/xltoolbar.hxx:25
     TBCCmd A _Bool
 sc/source/filter/excel/xltoolbar.hxx:26
@@ -564,20 +568,6 @@ sc/source/filter/excel/xltoolbar.hxx:29
     TBCCmd reserved3 sal_uInt16
 sc/source/filter/excel/xltoolbar.hxx:54
     ScCTB rVisualData std::vector<TBVisualData>
-sc/source/filter/excel/xltoolbar.hxx:55
-    ScCTB ectbid sal_uInt32
-sc/source/filter/excel/xltoolbar.hxx:73
-    CTBS bSignature sal_uInt8
-sc/source/filter/excel/xltoolbar.hxx:74
-    CTBS bVersion sal_uInt8
-sc/source/filter/excel/xltoolbar.hxx:75
-    CTBS reserved1 sal_uInt16
-sc/source/filter/excel/xltoolbar.hxx:76
-    CTBS reserved2 sal_uInt16
-sc/source/filter/excel/xltoolbar.hxx:77
-    CTBS reserved3 sal_uInt16
-sc/source/filter/excel/xltoolbar.hxx:80
-    CTBS ictbView sal_uInt16
 sc/source/filter/excel/xltools.cxx:100
      smD union sal_math_Double
 sc/source/filter/html/htmlpars.cxx:3012
@@ -586,6 +576,8 @@ sc/source/filter/html/htmlpars.cxx:3013
     (anonymous namespace)::CSSHandler maPropValue struct (anonymous namespace)::CSSHandler::MemStr
 sc/source/filter/inc/exp_op.hxx:47
     ExportBiff5 pExcRoot struct RootData *
+sc/source/filter/inc/formel.hxx:83
+    ConverterBase pBuffer std::unique_ptr<sal_Char []>
 sc/source/filter/inc/imp_op.hxx:84
     ImportExcel::LastFormula mpCell class ScFormulaCell *
 sc/source/filter/inc/namebuff.hxx:36
@@ -594,26 +586,18 @@ sc/source/filter/inc/namebuff.hxx:37
     StringHashEntry nHash const sal_uInt32
 sc/source/filter/inc/orcusinterface.hxx:376
     ScOrcusStyles::fill maBgColor class Color
-sc/source/filter/inc/orcusinterface.hxx:385
-    ScOrcusStyles maCurrentFill struct ScOrcusStyles::fill
-sc/source/filter/inc/orcusinterface.hxx:423
-    ScOrcusStyles maCurrentProtection struct ScOrcusStyles::protection
-sc/source/filter/inc/orcusinterface.hxx:436
-    ScOrcusStyles maCurrentNumberFormat struct ScOrcusStyles::number_format
 sc/source/filter/inc/orcusinterface.hxx:446
     ScOrcusStyles::xf mnStyleXf size_t
-sc/source/filter/inc/orcusinterface.hxx:457
-    ScOrcusStyles maCurrentXF struct ScOrcusStyles::xf
 sc/source/filter/inc/orcusinterface.hxx:466
     ScOrcusStyles::cell_style mnBuiltInId size_t
 sc/source/filter/inc/root.hxx:91
     LOTUS_ROOT eActType enum Lotus123Typ
-sc/source/filter/inc/root.hxx:92
-    LOTUS_ROOT aActRange class ScRange
 sc/source/filter/inc/tokstack.hxx:142
     TokenPool pP_Err TokenPoolPool<sal_uInt16, 8>
 sc/source/filter/oox/biffhelper.cxx:38
     oox::xls::(anonymous namespace)::DecodedDouble maStruct union sal_math_Double
+sc/source/filter/xml/XMLChangeTrackingExportHelper.hxx:46
+    ScChangeTrackingExportHelper pDependings std::unique_ptr<ScChangeActionMap>
 sc/source/filter/xml/xmlcondformat.hxx:111
     ScXMLIconSetFormatContext mpFormatData struct ScIconSetFormatData *
 sc/source/filter/xml/XMLDetectiveContext.hxx:97
@@ -624,14 +608,16 @@ sc/source/filter/xml/xmldrani.hxx:72
     ScXMLDatabaseRangeContext bIsSelection _Bool
 sc/source/filter/xml/xmlexternaltabi.hxx:113
     ScXMLExternalRefCellContext mnCellType sal_Int16
-sc/source/ui/docshell/externalrefmgr.cxx:163
-    (anonymous namespace)::RemoveFormulaCell mpCell class ScFormulaCell *const
 sc/source/ui/inc/AccessibleText.hxx:194
     ScAccessiblePreviewHeaderCellTextData mbRowHeader const _Bool
 sc/source/ui/inc/datastream.hxx:105
     sc::DataStream mnSettings sal_uInt32
+sc/source/ui/inc/drawview.hxx:42
+    ScDrawView pDropMarker std::unique_ptr<SdrDropMarkerOverlay>
 sc/source/ui/inc/drwtrans.hxx:45
     ScDrawTransferObj m_aDrawPersistRef SfxObjectShellRef
+sc/source/ui/inc/filtdlg.hxx:174
+    ScSpecialFilterDlg pOptionsMgr std::unique_ptr<ScFilterOptionsMgr>
 sc/source/ui/inc/instbdlg.hxx:57
     ScInsertTableDlg aDocShTablesRef SfxObjectShellRef
 sc/source/ui/inc/linkarea.hxx:37
@@ -646,36 +632,70 @@ sc/source/ui/inc/preview.hxx:47
     ScPreview nTabPage long
 sc/source/ui/inc/tabvwsh.hxx:120
     ScTabViewShell xDisProvInterceptor css::uno::Reference<css::frame::XDispatchProviderInterceptor>
+sc/source/ui/inc/tabvwsh.hxx:125
+    ScTabViewShell pPivotSource std::unique_ptr<ScArea>
 sc/source/ui/inc/transobj.hxx:47
     ScTransferObj m_aDrawPersistRef SfxObjectShellRef
 sc/source/ui/inc/uiitems.hxx:47
     ScInputStatusItem aStartPos const class ScAddress
 sc/source/ui/inc/uiitems.hxx:48
     ScInputStatusItem aEndPos const class ScAddress
-scripting/source/vbaevents/eventhelper.cxx:183
-    TranslatePropMap aTransInfo const struct TranslateInfo
-sd/source/filter/ppt/ppt97animations.hxx:41
-    Ppt97AnimationInfoAtom nSlideCount sal_uInt16
-sd/source/filter/ppt/ppt97animations.hxx:47
-    Ppt97AnimationInfoAtom nOLEVerb sal_uInt8
-sd/source/filter/ppt/ppt97animations.hxx:50
-    Ppt97AnimationInfoAtom nUnknown1 sal_uInt8
-sd/source/filter/ppt/ppt97animations.hxx:51
-    Ppt97AnimationInfoAtom nUnknown2 sal_uInt8
-sd/source/ui/inc/inspagob.hxx:33
-    SdInsertPagesObjsDlg m_pDoc const class SdDrawDocument *
+sc/source/ui/vba/vbachartobject.hxx:44
+    ScVbaChartObject oShapeHelper std::unique_ptr<ov::ShapeHelper>
+sd/inc/sdmod.hxx:132
+    SdModule mpErrorHdl std::unique_ptr<SfxErrorHandler>
+sd/source/ui/framework/module/ToolBarModule.hxx:75
+    sd::framework::ToolBarModule mpToolBarManagerLock std::unique_ptr<ToolBarManager::UpdateLock, o3tl::default_delete<ToolBarManager::UpdateLock> >
+sd/source/ui/inc/AccessibleDocumentViewBase.hxx:245
+    accessibility::AccessibleDocumentViewBase mpWindow VclPtr< ::sd::Window>
+sd/source/ui/inc/animobjs.hxx:124
+    sd::AnimationWindow pControllerItem std::unique_ptr<AnimationControllerItem>
+sd/source/ui/inc/fudspord.hxx:51
+    sd::FuDisplayOrder mpOverlay std::unique_ptr<SdrDropMarkerOverlay>
+sd/source/ui/inc/navigatr.hxx:124
+    SdNavigatorWin mpNavigatorCtrlItem std::unique_ptr<SdNavigatorControllerItem>
+sd/source/ui/inc/navigatr.hxx:125
+    SdNavigatorWin mpPageNameCtrlItem std::unique_ptr<SdPageNameControllerItem>
+sd/source/ui/inc/tools/TimerBasedTaskExecution.hxx:73
+    sd::tools::TimerBasedTaskExecution mpSelf std::shared_ptr<TimerBasedTaskExecution>
 sd/source/ui/inc/unopage.hxx:277
     SdPageLinkTargets mxPage css::uno::Reference<css::drawing::XDrawPage>
+sd/source/ui/inc/ViewShellImplementation.hxx:76
+    sd::ViewShell::Implementation::ToolBarManagerLock mpLock ::std::unique_ptr<ToolBarManager::UpdateLock, o3tl::default_delete<ToolBarManager::UpdateLock> >
+sd/source/ui/inc/ViewShellImplementation.hxx:87
+    sd::ViewShell::Implementation::ToolBarManagerLock mpSelf std::shared_ptr<ToolBarManagerLock>
 sd/source/ui/remotecontrol/Receiver.hxx:35
     sd::Receiver pTransmitter class sd::Transmitter *
 sd/source/ui/sidebar/MasterPageContainerProviders.hxx:136
     sd::sidebar::TemplatePreviewProvider msURL const class rtl::OUString
 sd/source/ui/sidebar/SlideBackground.hxx:94
     sd::sidebar::SlideBackground m_pContainer VclPtr<class VclVBox>
+sd/source/ui/slideshow/slideshowimpl.hxx:333
+    sd::SlideshowImpl mpPaneHider ::std::unique_ptr<PaneHider>
+sd/source/ui/slideshow/SlideShowRestarter.hxx:70
+    sd::SlideShowRestarter mpSelf ::std::shared_ptr<SlideShowRestarter>
+sd/source/ui/slidesorter/controller/SlsListener.hxx:147
+    sd::slidesorter::controller::Listener mpModelChangeLock std::shared_ptr<SlideSorterController::ModelChangeLock>
+sd/source/ui/slidesorter/inc/controller/SlsClipboard.hxx:119
+    sd::slidesorter::controller::Clipboard mxUndoContext std::unique_ptr<UndoContext>
+sd/source/ui/slidesorter/inc/view/SlsFontProvider.hxx:57
+    sd::slidesorter::view::FontProvider maFont std::shared_ptr<vcl::Font>
+sd/source/ui/view/ToolBarManager.cxx:320
+    sd::ToolBarManager::Implementation mpAsynchronousLayouterLock ::std::unique_ptr<LayouterLock>
+sdext/source/presenter/PresenterTimer.cxx:106
+    sdext::presenter::(anonymous namespace)::TimerScheduler mpLateDestroy std::shared_ptr<TimerScheduler>
 sfx2/source/appl/fileobj.hxx:37
     SvFileObject mxDelMed tools::SvRef<SfxMedium>
-sfx2/source/dialog/filtergrouping.cxx:340
-    sfx2::ReferToFilterEntry m_aClassPos FilterGroup::iterator
+sfx2/source/doc/sfxbasemodel.cxx:447
+    SfxSaveGuard m_pFramesLock std::unique_ptr<SfxOwnFramesLocker>
+sfx2/source/inc/appdata.hxx:76
+    SfxAppData_Impl pDocTopics std::unique_ptr<SfxDdeDocTopics_Impl>
+sfx2/source/inc/appdata.hxx:77
+    SfxAppData_Impl pTriggerTopic std::unique_ptr<SfxDdeTriggerTopic_Impl>
+sfx2/source/inc/appdata.hxx:78
+    SfxAppData_Impl pDdeService2 std::unique_ptr<DdeService>
+sfx2/source/inc/appdata.hxx:92
+    SfxAppData_Impl mxAppPickList std::unique_ptr<SfxPickList>
 sfx2/source/inc/splitwin.hxx:51
     SfxSplitWindow pActive VclPtr<class SfxDockingWindow>
 sfx2/source/view/classificationcontroller.cxx:61
@@ -686,6 +706,8 @@ slideshow/source/engine/opengl/TransitionImpl.hxx:297
     Vertex texcoord glm::vec2
 slideshow/source/engine/slideshowimpl.cxx:1044
     (anonymous namespace)::SlideShowImpl::PrefetchPropertiesFunc mpSlideShowImpl class (anonymous namespace)::SlideShowImpl *const
+slideshow/source/inc/animatedsprite.hxx:153
+    slideshow::internal::AnimatedSprite maTransform ::boost::optional< ::basegfx::B2DHomMatrix>
 slideshow/test/testview.cxx:53
     ImplTestView maCreatedSprites std::vector<std::pair<basegfx::B2DVector, double> >
 slideshow/test/testview.cxx:56
@@ -694,14 +716,8 @@ soltools/cpp/cpp.h:143
     macroValidator pMacro Nlist *
 starmath/inc/view.hxx:156
     SmCmdBoxWindow aController class SmEditController
-stoc/source/corereflection/lrucache.hxx:41
-    LRU_Cache::CacheEntry aKey t_Key
-stoc/source/security/lru_cache.h:45
-    stoc_sec::lru_cache::Entry m_key t_key
 stoc/source/servicemanager/servicemanager.cxx:400
     (anonymous namespace)::OServiceManager m_SetLoadedFactories (anonymous namespace)::HashSet_Ref
-store/source/storbase.hxx:245
-    store::PageData m_aMarked store::PageData::L
 store/source/storbios.cxx:56
     OStoreSuperBlock m_nMarked sal_uInt32
 store/source/storbios.cxx:57
@@ -710,6 +726,8 @@ svgio/inc/svgcharacternode.hxx:89
     svgio::svgreader::SvgTextPosition maY ::std::vector<double>
 svgio/inc/svgsvgnode.hxx:44
     svgio::svgreader::SvgSvgNode maVersion class svgio::svgreader::SvgNumber
+svgio/inc/svgsymbolnode.hxx:38
+    svgio::svgreader::SvgSymbolNode mpViewBox std::unique_ptr<basegfx::B2DRange>
 svgio/inc/svgsymbolnode.hxx:39
     svgio::svgreader::SvgSymbolNode maSvgAspectRatio class svgio::svgreader::SvgAspectRatio
 svgio/inc/svgusenode.hxx:42
@@ -784,28 +802,20 @@ svx/source/svdraw/svdibrow.cxx:95
     ImpItemListRow pType const std::type_info *
 svx/source/svdraw/svdpdf.hxx:196
     ImpSdrPdfImport mdPageWidthPts double
-svx/source/table/tablertfimporter.cxx:54
-    sdr::table::RTFCellDefault maItemSet class SfxItemSet
 svx/source/tbxctrls/tbcontrl.cxx:195
     SvxFontNameBox_Impl m_aOwnFontList ::std::unique_ptr<FontList>
 sw/inc/accmap.hxx:96
     SwAccessibleMap mvShapes SwShapeList_Impl
-sw/inc/shellio.hxx:150
-    SwReader aFileName const class rtl::OUString
-sw/inc/shellio.hxx:151
-    SwReader sBaseURL class rtl::OUString
+sw/inc/swmodule.hxx:95
+    SwModule m_pErrorHandler std::unique_ptr<SfxErrorHandler>
 sw/inc/swmodule.hxx:108
     SwModule m_xLinguServiceEventListener css::uno::Reference<css::linguistic2::XLinguServiceEventListener>
 sw/inc/swwait.hxx:45
     SwWait mpLockedDispatchers std::unordered_set<SfxDispatcher *>
-sw/inc/ToxTabStopTokenHandler.hxx:38
-    sw::ToxTabStopTokenHandler::HandledTabStopToken tabStop class SvxTabStop
 sw/inc/unoframe.hxx:314
     SwXOLEListener m_xOLEModel css::uno::Reference<css::frame::XModel>
-sw/source/core/doc/tblafmt.cxx:165
-    SwAfVersions m_nVerticalAlignmentVersion sal_uInt16
-sw/source/core/inc/docsort.hxx:102
-    SwSortTextElement nOrg const sal_uLong
+sw/inc/view.hxx:184
+    SwView m_xGlueDocShell std::unique_ptr<SwViewGlueDocShell>
 sw/source/core/inc/swfont.hxx:983
     SvStatistics nGetTextSize sal_uInt16
 sw/source/core/inc/swfont.hxx:984
@@ -834,10 +844,12 @@ sw/source/filter/inc/rtf.hxx:30
     RTFSurround::(anonymous union)::(anonymous) nJunk sal_uInt8
 sw/source/filter/inc/rtf.hxx:31
     RTFSurround::(anonymous) Flags struct (anonymous struct at /media/noel/disk2/libo5/sw/source/filter/inc/rtf.hxx:27:9)
-sw/source/ui/frmdlg/frmpage.cxx:717
-    (anonymous namespace)::FrameMaps pMap const struct FrameMap *
-sw/source/ui/frmdlg/frmpage.cxx:776
-    (anonymous namespace)::RelationMaps pMap const struct RelationMap *
+sw/source/uibase/inc/column.hxx:133
+    SwColumnPage m_xDefaultVS std::unique_ptr<weld::CustomWeld>
+sw/source/uibase/inc/frmpage.hxx:226
+    SwGrfExtPage m_xCtlAngle std::unique_ptr<weld::CustomWeld>
+sw/source/uibase/inc/frmpage.hxx:227
+    SwGrfExtPage m_xBmpWin std::unique_ptr<weld::CustomWeld>
 sw/source/uibase/inc/glossary.hxx:69
     SwGlossaryDlg m_xGroupData std::vector<std::unique_ptr<GroupUserData> >
 sw/source/uibase/inc/maildispatcher.hxx:146
@@ -846,6 +858,8 @@ sw/source/uibase/inc/maildispatcher.hxx:152
     MailDispatcher m_xSelfReference ::rtl::Reference<MailDispatcher>
 sw/source/uibase/inc/redlndlg.hxx:66
     SwRedlineAcceptDlg m_aUsedSeqNo class SwRedlineDataParentSortArr
+sw/source/uibase/inc/swuicnttab.hxx:79
+    SwMultiTOXTabDialog m_xExampleFrameWin std::unique_ptr<weld::CustomWeld>
 testtools/source/bridgetest/cppobj.cxx:149
     bridge_object::Test_Impl _arStruct Sequence<struct test::testtools::bridgetest::TestElement>
 ucb/source/ucp/gio/gio_mount.hxx:74
@@ -862,8 +876,6 @@ ucb/source/ucp/webdav-neon/NeonSession.cxx:162
     NeonRequestContext pResource struct webdav_ucp::DAVResource *
 unoidl/source/legacyprovider.cxx:86
     unoidl::detail::(anonymous namespace)::Cursor manager_ rtl::Reference<Manager>
-unoidl/source/sourceprovider-scanner.hxx:119
-    unoidl::detail::SourceProviderInterfaceTypeEntityPad::DirectBase annotations std::vector<OUString>
 unoidl/source/unoidl.cxx:83
     unoidl::(anonymous namespace)::AggregatingCursor seen_ std::set<OUString>
 unoidl/source/unoidlprovider.hxx:33
@@ -912,15 +924,17 @@ unotools/source/config/defaultoptions.cxx:90
     SvtDefaultOptions_Impl m_aWorkPath class rtl::OUString
 unotools/source/config/defaultoptions.cxx:91
     SvtDefaultOptions_Impl m_aClassificationPath class rtl::OUString
-unotools/source/misc/fontcvt.cxx:1041
-    ExtraTable cStar sal_Unicode
+unoxml/source/rdf/librdf_repository.cxx:464
+    (anonymous namespace)::librdf_GraphResult m_pQuery const std::shared_ptr<librdf_query>
+unoxml/source/rdf/librdf_repository.cxx:574
+    (anonymous namespace)::librdf_QuerySelectResult m_pQuery const std::shared_ptr<librdf_query>
 unoxml/source/xpath/nodelist.hxx:52
     XPath::CNodeList m_pXPathObj std::shared_ptr<xmlXPathObject>
 vbahelper/source/vbahelper/vbafillformat.hxx:36
     ScVbaFillFormat m_nForeColor sal_Int32
 vcl/inc/accel.h:33
     ImplAccelEntry mpAutoAccel class Accelerator *
-vcl/inc/fontselect.hxx:62
+vcl/inc/fontselect.hxx:61
     FontSelectPattern mfExactHeight float
 vcl/inc/opengl/RenderList.hxx:29
     Vertex color glm::vec4
@@ -932,6 +946,8 @@ vcl/inc/qt5/Qt5Frame.hxx:77
     Qt5Frame m_pSalMenu class Qt5Menu *
 vcl/inc/qt5/Qt5Graphics.hxx:56
     Qt5Graphics m_pFontCollection class PhysicalFontCollection *
+vcl/inc/qt5/Qt5Instance.hxx:59
+    Qt5Instance m_pQApplication std::unique_ptr<QApplication>
 vcl/inc/qt5/Qt5Instance.hxx:60
     Qt5Instance m_pFakeArgvFreeable std::vector<FreeableCStr>
 vcl/inc/qt5/Qt5Instance.hxx:61
@@ -970,7 +986,7 @@ vcl/inc/salwtype.hxx:243
     SalInputContext mpFont rtl::Reference<LogicalFontInstance>
 vcl/inc/salwtype.hxx:250
     SalSwipeEvent mnVelocityY double
-vcl/inc/sft.hxx:483
+vcl/inc/sft.hxx:478
     vcl::TrueTypeFont mapper sal_uInt32 (*)(const sal_uInt8 *, sal_uInt32, sal_uInt32)
 vcl/inc/svdata.hxx:423
     ImplSVEvent mpInstanceRef VclPtr<vcl::Window>
@@ -1008,8 +1024,6 @@ vcl/source/gdi/pdfwriter_impl.hxx:181
     vcl::PDFWriterImpl::BitmapID m_nChecksum BitmapChecksum
 vcl/source/gdi/pdfwriter_impl.hxx:182
     vcl::PDFWriterImpl::BitmapID m_nMaskChecksum BitmapChecksum
-vcl/source/gdi/pdfwriter_impl.hxx:467
-    vcl::PDFWriterImpl::PDFWidget m_nTabOrder sal_Int32
 vcl/unx/generic/app/wmadaptor.cxx:1264
     _mwmhints flags unsigned long
 vcl/unx/generic/app/wmadaptor.cxx:1264
@@ -1028,6 +1042,8 @@ vcl/unx/generic/gdi/cairotextrender.cxx:56
     (anonymous namespace)::CairoFontsCache::CacheId mbVerticalMetrics _Bool
 vcl/unx/gtk3/gtk3gtkinst.cxx:1168
      in char *
+vcl/unx/gtk3/gtk3gtkinst.cxx:3045
+    GtkInstanceDialog m_xDialogController std::shared_ptr<weld::DialogController>
 vcl/unx/gtk/a11y/atkutil.cxx:142
     DocumentFocusListener m_aRefList std::set<uno::Reference<uno::XInterface> >
 vcl/unx/gtk/a11y/atkwrapper.hxx:49
@@ -1046,8 +1062,6 @@ vcl/workben/vcldemo.cxx:1740
     DemoWin mxThread rtl::Reference<RenderThread>
 writerfilter/source/dmapper/PropertyMap.hxx:198
     writerfilter::dmapper::SectionPropertyMap m_nDebugSectionNumber sal_Int32
-writerfilter/source/dmapper/SectionColumnHandler.hxx:44
-    writerfilter::dmapper::SectionColumnHandler m_aTempColumn struct writerfilter::dmapper::Column_
 xmlhelp/source/cxxhelp/provider/databases.hxx:261
     chelp::Databases m_aDatabases chelp::Databases::DatabasesTable
 xmlhelp/source/cxxhelp/provider/databases.hxx:267
@@ -1058,11 +1072,19 @@ xmlhelp/source/cxxhelp/provider/databases.hxx:276
     chelp::Databases m_aZipFileTable chelp::Databases::ZipFileTable
 xmlhelp/source/cxxhelp/provider/databases.hxx:282
     chelp::Databases m_aCollatorTable chelp::Databases::CollatorTable
-xmloff/inc/XMLElementPropertyContext.hxx:37
-    XMLElementPropertyContext aProp struct XMLPropertyState
 xmloff/source/draw/ximpstyl.hxx:221
     SdXMLMasterStylesContext maMasterPageList std::vector<rtl::Reference<SdXMLMasterPageContext> >
+xmloff/source/forms/elementexport.hxx:47
+    xmloff::OElementExport m_pXMLElement std::unique_ptr<SvXMLElementExport>
+xmloff/source/forms/elementexport.hxx:104
+    xmloff::OControlExport m_pOuterElement std::unique_ptr<SvXMLElementExport>
+xmloff/source/forms/officeforms.hxx:65
+    xmloff::OFormsRootExport m_pImplElement std::unique_ptr<SvXMLElementExport>
 xmloff/source/text/txtimp.cxx:523
     XMLTextImportHelper::Impl m_xFrameImpPrMap rtl::Reference<SvXMLImportPropertyMapper>
 xmlsecurity/inc/certificatechooser.hxx:55
     CertificateChooser mvUserData std::vector<std::shared_ptr<UserData> >
+xmlsecurity/inc/certificateviewer.hxx:55
+    CertificateViewer mxGeneralPage std::unique_ptr<CertificateViewerGeneralTP>
+xmlsecurity/inc/certificateviewer.hxx:56
+    CertificateViewer mxDetailsPage std::unique_ptr<CertificateViewerDetailsTP>
diff --git a/include/sfx2/basedlgs.hxx b/include/sfx2/basedlgs.hxx
index 7ef1d185f41c..4edf52e46f04 100644
--- a/include/sfx2/basedlgs.hxx
+++ b/include/sfx2/basedlgs.hxx
@@ -43,7 +43,6 @@ class Timer;
 class SFX2_DLLPUBLIC SfxModalDialog: public ModalDialog
 {
     OUString                aExtraData;
-    std::unique_ptr<SfxItemSet> pOutputSet;
 
 private:
     SfxModalDialog(SfxModalDialog const &) = delete;
@@ -66,7 +65,6 @@ class SfxModelessDialog_Impl;
 class SFX2_DLLPUBLIC SfxModelessDialog: public ModelessDialog
 {
     SfxBindings*            pBindings;
-    Size                    aSize;
     std::unique_ptr< SfxModelessDialog_Impl > pImpl;
 
     SfxModelessDialog(SfxModelessDialog const &) = delete;
diff --git a/include/svx/dlgctl3d.hxx b/include/svx/dlgctl3d.hxx
index 4ff4defc36c0..d979e5fda32f 100644
--- a/include/svx/dlgctl3d.hxx
+++ b/include/svx/dlgctl3d.hxx
@@ -247,7 +247,6 @@ class SAL_WARN_UNUSED SVX_DLLPUBLIC SvxLightCtl3D final : public Control
     VclPtr<PushButton>         maSwitcher;
 
     // callback for interactive changes
-    Link<SvxLightCtl3D*,void>  maUserInteractiveChangeCallback;
     Link<SvxLightCtl3D*,void>  maUserSelectionChangeCallback;
 
 public:
diff --git a/include/svx/ruler.hxx b/include/svx/ruler.hxx
index d69c4f672f0a..b27b49ca1b27 100644
--- a/include/svx/ruler.hxx
+++ b/include/svx/ruler.hxx
@@ -91,7 +91,6 @@ class SVX_DLLPUBLIC SvxRuler: public Ruler, public SfxListener
     std::unique_ptr<SvxLongULSpaceItem> mxULSpaceItem;    // upper and lower edge
     std::unique_ptr<SvxTabStopItem>     mxTabStopItem;    // tab stops
     std::unique_ptr<SvxLRSpaceItem>     mxParaItem;       // paragraphs
-    std::unique_ptr<SvxLRSpaceItem>     mxParaBorderItem; // border distance
     std::unique_ptr<SvxPagePosSizeItem> mxPagePosItem;    // page distance to the rule
     std::unique_ptr<SvxColumnItem>      mxColumnItem;     // columns
     std::unique_ptr<SvxObjectItem>      mxObjectItem;     // object
@@ -141,7 +140,7 @@ class SVX_DLLPUBLIC SvxRuler: public Ruler, public SfxListener
     // paragraph indentations
     void UpdatePara(const SvxLRSpaceItem* pItem);
     // Border distance
-    void UpdateParaBorder(const SvxLRSpaceItem* pItem);
+    void UpdateParaBorder();
     // Tabs
     void Update(const SvxTabStopItem* pItem);
     // page position and width
diff --git a/sc/source/filter/excel/frmbase.cxx b/sc/source/filter/excel/frmbase.cxx
index 9fbd5489487f..35bba553997e 100644
--- a/sc/source/filter/excel/frmbase.cxx
+++ b/sc/source/filter/excel/frmbase.cxx
@@ -148,12 +148,10 @@ const ScRange* ScRangeListTabs::Next ()
     return &(*maItrCur);
 }
 
-ConverterBase::ConverterBase( svl::SharedStringPool& rSPool, sal_uInt16 nNewBuffer ) :
+ConverterBase::ConverterBase( svl::SharedStringPool& rSPool ) :
     aPool(rSPool),
     aEingPos( 0, 0, 0 )
 {
-    OSL_ENSURE( nNewBuffer > 0, "ConverterBase::ConverterBase - nNewBuffer == 0!" );
-    pBuffer.reset( new sal_Char[ nNewBuffer ] );
 }
 
 ConverterBase::~ConverterBase()
@@ -167,7 +165,7 @@ void ConverterBase::Reset()
 }
 
 ExcelConverterBase::ExcelConverterBase( svl::SharedStringPool& rSPool ) :
-    ConverterBase(rSPool, 512)
+    ConverterBase(rSPool)
 {
 }
 
@@ -188,7 +186,7 @@ void ExcelConverterBase::Reset()
 }
 
 LotusConverterBase::LotusConverterBase( SvStream &rStr, svl::SharedStringPool& rSPool  ) :
-    ConverterBase(rSPool, 128),
+    ConverterBase(rSPool),
     aIn( rStr ),
     nBytesLeft( 0 )
 {
diff --git a/sc/source/filter/inc/formel.hxx b/sc/source/filter/inc/formel.hxx
index bda80896809e..3dea5ea572cd 100644
--- a/sc/source/filter/inc/formel.hxx
+++ b/sc/source/filter/inc/formel.hxx
@@ -79,10 +79,8 @@ protected:
     TokenPool           aPool;          // user token + predefined token
     TokenStack          aStack;
     ScAddress           aEingPos;
-    std::unique_ptr<sal_Char[]>
-                        pBuffer;        // universal buffer
 
-    ConverterBase( svl::SharedStringPool& rSPool, sal_uInt16 nNewBuffer );
+    ConverterBase( svl::SharedStringPool& rSPool );
     virtual             ~ConverterBase();
 
     void                Reset();
diff --git a/sc/source/filter/qpro/qproform.cxx b/sc/source/filter/qpro/qproform.cxx
index bd1ea7fc092a..e549c0356917 100644
--- a/sc/source/filter/qpro/qproform.cxx
+++ b/sc/source/filter/qpro/qproform.cxx
@@ -62,7 +62,7 @@ void QProToSc::ReadSRD( ScSingleRefData& rSRD, sal_Int8 nPage, sal_Int8 nCol, sa
 }
 
 QProToSc::QProToSc( SvStream& rStream, svl::SharedStringPool& rSPool, const ScAddress& rRefPos ) :
-    ConverterBase(rSPool, 128),
+    ConverterBase(rSPool),
     maIn( rStream )
 {
     aEingPos = rRefPos;
diff --git a/sc/source/filter/xml/XMLChangeTrackingExportHelper.cxx b/sc/source/filter/xml/XMLChangeTrackingExportHelper.cxx
index 51e45769ce4c..4502e7ec699f 100644
--- a/sc/source/filter/xml/XMLChangeTrackingExportHelper.cxx
+++ b/sc/source/filter/xml/XMLChangeTrackingExportHelper.cxx
@@ -45,7 +45,6 @@ ScChangeTrackingExportHelper::ScChangeTrackingExportHelper(ScXMLExport& rTempExp
     pEditTextObj(nullptr)
 {
     pChangeTrack = rExport.GetDocument() ? rExport.GetDocument()->GetChangeTrack() : nullptr;
-    pDependings.reset( new ScChangeActionMap );
 }
 
 ScChangeTrackingExportHelper::~ScChangeTrackingExportHelper()
diff --git a/sc/source/filter/xml/XMLChangeTrackingExportHelper.hxx b/sc/source/filter/xml/XMLChangeTrackingExportHelper.hxx
index fb5ccaf6bb24..9ca715360cf1 100644
--- a/sc/source/filter/xml/XMLChangeTrackingExportHelper.hxx
+++ b/sc/source/filter/xml/XMLChangeTrackingExportHelper.hxx
@@ -35,15 +35,12 @@ class ScChangeActionDel;
 class ScBigRange;
 class ScEditEngineTextObj;
 
-typedef std::map<sal_uLong, ScChangeAction*> ScChangeActionMap;
-
 class ScChangeTrackingExportHelper
 {
     ScXMLExport&    rExport;
 
     ScChangeTrack*  pChangeTrack;
     ScEditEngineTextObj* pEditTextObj;
-    std::unique_ptr<ScChangeActionMap> pDependings;
     css::uno::Reference<css::text::XText> xText;
 
     static OUString GetChangeID(const sal_uInt32 nActionNumber);
diff --git a/sc/source/ui/inc/tabvwsh.hxx b/sc/source/ui/inc/tabvwsh.hxx
index 7d51dbc5c7fa..3aa575aaa0da 100644
--- a/sc/source/ui/inc/tabvwsh.hxx
+++ b/sc/source/ui/inc/tabvwsh.hxx
@@ -122,7 +122,6 @@ private:
     Point                   aWinPos;
 
     ScTabViewTarget         aTarget;
-    std::unique_ptr<ScArea>     pPivotSource;
     std::unique_ptr<ScDPObject> pDialogDPObject;
 
     std::unique_ptr<ScNavigatorSettings> pNavSettings;
diff --git a/sc/source/ui/view/tabvwsh4.cxx b/sc/source/ui/view/tabvwsh4.cxx
index 46259a8f12a3..b1a24d27df93 100644
--- a/sc/source/ui/view/tabvwsh4.cxx
+++ b/sc/source/ui/view/tabvwsh4.cxx
@@ -1449,7 +1449,6 @@ void ScTabViewShell::Construct( TriState nForceDesignMode )
     SetWindow( GetActiveWin() );
 
     pCurFrameLine.reset( new ::editeng::SvxBorderLine(&aColBlack, 20, SvxBorderLineStyle::SOLID) );
-    pPivotSource.reset( new ScArea );
     StartListening(*GetViewData().GetDocShell(), DuplicateHandling::Prevent);
     StartListening(*GetViewFrame(), DuplicateHandling::Prevent);
     StartListening(*pSfxApp, DuplicateHandling::Prevent); // #i62045# #i62046# application is needed for Calc's own hints
@@ -1778,7 +1777,6 @@ ScTabViewShell::~ScTabViewShell()
     pAuditingShell.reset();
     pCurFrameLine.reset();
     mpInputHandler.reset();
-    pPivotSource.reset();
     pDialogDPObject.reset();
     pNavSettings.reset();
 
diff --git a/sd/Library_sd.mk b/sd/Library_sd.mk
index 85953e285575..87fd3332594f 100644
--- a/sd/Library_sd.mk
+++ b/sd/Library_sd.mk
@@ -390,7 +390,6 @@ $(eval $(call gb_Library_add_exception_objects,sd,\
 	sd/source/ui/slidesorter/shell/SlideSorterService \
 	sd/source/ui/slidesorter/shell/SlideSorterViewShell \
 	sd/source/ui/slidesorter/view/SlideSorterView \
-	sd/source/ui/slidesorter/view/SlsFontProvider \
 	sd/source/ui/slidesorter/view/SlsFramePainter \
 	sd/source/ui/slidesorter/view/SlsInsertAnimator \
 	sd/source/ui/slidesorter/view/SlsInsertionIndicatorOverlay \
diff --git a/sd/source/ui/slidesorter/controller/SlideSorterController.cxx b/sd/source/ui/slidesorter/controller/SlideSorterController.cxx
index bb4f44ce0649..8b36fbb7604e 100644
--- a/sd/source/ui/slidesorter/controller/SlideSorterController.cxx
+++ b/sd/source/ui/slidesorter/controller/SlideSorterController.cxx
@@ -39,7 +39,6 @@
 #include <model/SlsPageDescriptor.hxx>
 #include <view/SlideSorterView.hxx>
 #include <view/SlsLayouter.hxx>
-#include <view/SlsFontProvider.hxx>
 #include <view/SlsPageObjectLayouter.hxx>
 #include <view/SlsPageObjectPainter.hxx>
 #include <view/SlsTheme.hxx>
@@ -568,7 +567,6 @@ IMPL_LINK(SlideSorterController, WindowEventHandler, VclWindowEvent&, rEvent, vo
 
                 // When the system font has changed a layout has to be done.
                 mrView.Resize();
-                FontProvider::Instance().Invalidate();
 
                 // Update theme colors.
                 mrSlideSorter.GetProperties()->HandleDataChangeEvent();
diff --git a/sd/source/ui/slidesorter/inc/view/SlsFontProvider.hxx b/sd/source/ui/slidesorter/inc/view/SlsFontProvider.hxx
deleted file mode 100644
index 3705546a8a56..000000000000
--- a/sd/source/ui/slidesorter/inc/view/SlsFontProvider.hxx
+++ /dev/null
@@ -1,70 +0,0 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*
- * This file is part of the LibreOffice project.
- *
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- *
- * This file incorporates work covered by the following license notice:
- *
- *   Licensed to the Apache Software Foundation (ASF) under one or more
- *   contributor license agreements. See the NOTICE file distributed
- *   with this work for additional information regarding copyright
- *   ownership. The ASF licenses this file to you under the Apache
- *   License, Version 2.0 (the "License"); you may not use this file
- *   except in compliance with the License. You may obtain a copy of
- *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
- */
-
-#ifndef INCLUDED_SD_SOURCE_UI_SLIDESORTER_INC_VIEW_SLSFONTPROVIDER_HXX
-#define INCLUDED_SD_SOURCE_UI_SLIDESORTER_INC_VIEW_SLSFONTPROVIDER_HXX
-
-#include <tools/SdGlobalResourceContainer.hxx>
-
-#include <memory>
-
-namespace vcl { class Font; }
-
-namespace sd { namespace slidesorter { namespace view {
-
-/** This simple singleton class provides fonts that are scaled so that they
-    have a fixed height on the given device regardless of its map mode.
-*/
-class FontProvider
-    : public SdGlobalResource
-{
-public:
-    /** Return the single instance of this class.  Throws a RuntimeException
-        when no instance can be created.
-    */
-    static FontProvider& Instance();
-
-    /** Call this method to tell an object to release its currently used
-        font.  The next call to GetFont() will then create a new one.
-        Typically called after a DataChange event when for instance a system
-        font has been modified.
-    */
-    void Invalidate();
-
-private:
-    static FontProvider* mpInstance;
-
-    /** The font that was created by a previous call to GetFont().  It is
-        replaced by another one only when GetFont() is called with a device
-        with a different map mode or by a call to Invalidate().
-    */
-    std::shared_ptr<vcl::Font> maFont;
-
-    FontProvider();
-    virtual ~FontProvider() override;
-
-    FontProvider (const FontProvider&) = delete;
-    FontProvider& operator= (const FontProvider&) = delete;
-};
-
-} } } // end of namespace ::sd::slidesorter::view
-
-#endif
-
-/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/sd/source/ui/slidesorter/view/SlsFontProvider.cxx b/sd/source/ui/slidesorter/view/SlsFontProvider.cxx
deleted file mode 100644
index 8bae88593d51..000000000000
--- a/sd/source/ui/slidesorter/view/SlsFontProvider.cxx
+++ /dev/null
@@ -1,82 +0,0 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*
- * This file is part of the LibreOffice project.
- *
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- *
- * This file incorporates work covered by the following license notice:
- *
- *   Licensed to the Apache Software Foundation (ASF) under one or more
- *   contributor license agreements. See the NOTICE file distributed
- *   with this work for additional information regarding copyright
- *   ownership. The ASF licenses this file to you under the Apache
- *   License, Version 2.0 (the "License"); you may not use this file
- *   except in compliance with the License. You may obtain a copy of
- *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
- */
-
-#include <memory>
-#include <view/SlsFontProvider.hxx>
-
-#include <controller/SlideSorterController.hxx>
-
-#include <sfx2/app.hxx>
-#include <osl/getglobalmutex.hxx>
-#include <com/sun/star/uno/RuntimeException.hpp>
-
-using namespace ::sd::slidesorter;
-
-namespace sd { namespace slidesorter { namespace view {
-
-FontProvider* FontProvider::mpInstance = nullptr;
-
-FontProvider& FontProvider::Instance()
-{
-    if (mpInstance == nullptr)
-    {
-        ::osl::GetGlobalMutex aMutexFunctor;
-        ::osl::MutexGuard aGuard (aMutexFunctor());
-        if (mpInstance == nullptr)
-        {
-            // Create an instance of the class and register it at the
-            // SdGlobalResourceContainer so that it is eventually released.
-            FontProvider* pInstance = new FontProvider();
-            SdGlobalResourceContainer::Instance().AddResource (
-                ::std::unique_ptr<SdGlobalResource>(pInstance));
-            OSL_DOUBLE_CHECKED_LOCKING_MEMORY_BARRIER();
-            mpInstance = pInstance;
-        }
-    }
-    else
-    {
-        OSL_DOUBLE_CHECKED_LOCKING_MEMORY_BARRIER();
-    }
-
-    // We throw an exception when for some strange reason no instance of
-    // this class exists.
-    if (mpInstance == nullptr)
-        throw css::uno::RuntimeException("com.sun.star.document.IndexedPropertyValues",
-            nullptr);
-
-    return *mpInstance;
-}
-
-FontProvider::FontProvider()
-    : maFont()
-{
-}
-
-FontProvider::~FontProvider()
-{
-}
-
-void FontProvider::Invalidate()
-{
-    maFont.reset();
-}
-
-} } }  // end of namespace ::sd::slidesorter::view
-
-/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/sd/source/ui/slidesorter/view/SlsPageObjectLayouter.cxx b/sd/source/ui/slidesorter/view/SlsPageObjectLayouter.cxx
index 93be4844ebbd..1c2edf958959 100644
--- a/sd/source/ui/slidesorter/view/SlsPageObjectLayouter.cxx
+++ b/sd/source/ui/slidesorter/view/SlsPageObjectLayouter.cxx
@@ -20,7 +20,6 @@
 #include <view/SlsPageObjectLayouter.hxx>
 
 #include <model/SlsPageDescriptor.hxx>
-#include <view/SlsFontProvider.hxx>
 #include <view/SlsTheme.hxx>
 #include <tools/IconCache.hxx>
 #include <Window.hxx>
diff --git a/sfx2/source/dialog/basedlgs.cxx b/sfx2/source/dialog/basedlgs.cxx
index 285ec29229bd..f902196eccbe 100644
--- a/sfx2/source/dialog/basedlgs.cxx
+++ b/sfx2/source/dialog/basedlgs.cxx
@@ -136,7 +136,6 @@ SfxModalDialog::~SfxModalDialog()
 void SfxModalDialog::dispose()
 {
     SetDialogData_Impl();
-    pOutputSet.reset();
 
     ModalDialog::dispose();
 }
@@ -154,8 +153,6 @@ void SfxModelessDialog::StateChanged( StateChangedType nStateChange )
             Point aPos = GetPosPixel();
             if ( !aPos.X() )
             {
-                aSize = GetSizePixel();
-
                 Size aParentSize = GetParent()->GetOutputSizePixel();
                 Size aDlgSize = GetSizePixel();
                 aPos.AdjustX(( aParentSize.Width() - aDlgSize.Width() ) / 2 );
@@ -223,8 +220,6 @@ IMPL_LINK_NOARG(SfxModelessDialog, TimerHdl, Timer *, void)
     pImpl->aMoveIdle.Stop();
     if ( pImpl->bConstructed && pImpl->pMgr )
     {
-        if ( !IsRollUp() )
-            aSize = GetSizePixel();
         WindowStateMask nMask = WindowStateMask::Pos | WindowStateMask::State;
         if ( GetStyle() & WB_SIZEABLE )
             nMask |= WindowStateMask::Width | WindowStateMask::Height;
diff --git a/slideshow/source/engine/animatedsprite.cxx b/slideshow/source/engine/animatedsprite.cxx
index 481a625afe7a..3a3279cee306 100644
--- a/slideshow/source/engine/animatedsprite.cxx
+++ b/slideshow/source/engine/animatedsprite.cxx
@@ -48,7 +48,6 @@ namespace slideshow
             mnAlpha(0.0),
             maPosPixel(),
             maClip(),
-            maTransform(),
             mbSpriteVisible( false )
         {
             ENSURE_OR_THROW( mpViewLayer, "AnimatedSprite::AnimatedSprite(): Invalid view layer" );
@@ -181,7 +180,6 @@ namespace slideshow
 
         void AnimatedSprite::transform( const ::basegfx::B2DHomMatrix& rTransform )
         {
-            maTransform.reset( rTransform );
             mpSprite->transform( rTransform );
         }
 
diff --git a/slideshow/source/inc/animatedsprite.hxx b/slideshow/source/inc/animatedsprite.hxx
index 7f4b16401cfc..3c215edc0d27 100644
--- a/slideshow/source/inc/animatedsprite.hxx
+++ b/slideshow/source/inc/animatedsprite.hxx
@@ -150,7 +150,6 @@ namespace slideshow
             double                                                      mnAlpha;
             ::boost::optional< ::basegfx::B2DPoint >                    maPosPixel;
             ::boost::optional< ::basegfx::B2DPolyPolygon >              maClip;
-            ::boost::optional< ::basegfx::B2DHomMatrix >                maTransform;
 
             bool                                                        mbSpriteVisible;
         };
diff --git a/svgio/inc/svgsymbolnode.hxx b/svgio/inc/svgsymbolnode.hxx
index 7cb2ac739555..555eabb2f99a 100644
--- a/svgio/inc/svgsymbolnode.hxx
+++ b/svgio/inc/svgsymbolnode.hxx
@@ -33,9 +33,6 @@ namespace svgio
             /// use styles
             SvgStyleAttributes      maSvgStyleAttributes;
 
-            /// variable scan values, dependent of given XAttributeList
-            std::unique_ptr<basegfx::B2DRange>
-                                    mpViewBox;
             SvgAspectRatio          maSvgAspectRatio;
 
         public:
@@ -46,9 +43,6 @@ namespace svgio
 
             virtual const SvgStyleAttributes* getSvgStyleAttributes() const override;
             virtual void parseAttribute(const OUString& rTokenName, SVGToken aSVGToken, const OUString& aContent) override;
-
-            /// viewBox content
-            void setViewBox(const basegfx::B2DRange* pViewBox) { mpViewBox.reset(); if(pViewBox) mpViewBox.reset( new basegfx::B2DRange(*pViewBox) ); }
         };
     } // end of namespace svgreader
 } // end of namespace svgio
diff --git a/svgio/source/svgreader/svgsymbolnode.cxx b/svgio/source/svgreader/svgsymbolnode.cxx
index 632067e8f954..45228cd8f37e 100644
--- a/svgio/source/svgreader/svgsymbolnode.cxx
+++ b/svgio/source/svgreader/svgsymbolnode.cxx
@@ -61,12 +61,7 @@ namespace svgio
                 }
                 case SVGTokenViewBox:
                 {
-                    const basegfx::B2DRange aRange(readViewBox(aContent, *this));
-
-                    if(!aRange.isEmpty())
-                    {
-                        setViewBox(&aRange);
-                    }
+                    readViewBox(aContent, *this);
                     break;
                 }
                 case SVGTokenPreserveAspectRatio:
diff --git a/svx/source/dialog/dlgctl3d.cxx b/svx/source/dialog/dlgctl3d.cxx
index 56c3f424a34c..c61a9472f2e9 100644
--- a/svx/source/dialog/dlgctl3d.cxx
+++ b/svx/source/dialog/dlgctl3d.cxx
@@ -1932,11 +1932,6 @@ void SvxLightCtl3D::move( double fDeltaHor, double fDeltaVer )
     maLightControl->SetPosition(fHor, fVer);
     maHorScroller->SetThumbPos( sal_Int32(fHor * 100.0) );
     maVerScroller->SetThumbPos( 18000 - sal_Int32((fVer + 90.0) * 100.0) );
-
-    if(maUserInteractiveChangeCallback.IsSet())
-    {
-        maUserInteractiveChangeCallback.Call(this);
-    }
 }
 
 void SvxLightCtl3D::KeyInput( const KeyEvent& rKEvt )
@@ -2083,11 +2078,6 @@ IMPL_LINK_NOARG(SvxLightCtl3D, ScrollBarMove, ScrollBar*, void)
     maLightControl->SetPosition(
         static_cast<double>(nHor) / 100.0,
         static_cast<double>((18000 - nVer) - 9000) / 100.0);
-
-    if(maUserInteractiveChangeCallback.IsSet())
-    {
-        maUserInteractiveChangeCallback.Call(this);
-    }
 }
 
 IMPL_LINK_NOARG(SvxLightCtl3D, ButtonPress, Button*, void)
@@ -2109,11 +2099,6 @@ IMPL_LINK_NOARG(SvxLightCtl3D, InternalInteractiveChange, Svx3DLightControl*, vo
     maLightControl->GetPosition(fHor, fVer);
     maHorScroller->SetThumbPos( sal_Int32(fHor * 100.0) );
     maVerScroller->SetThumbPos( 18000 - sal_Int32((fVer + 90.0) * 100.0) );
-
-    if(maUserInteractiveChangeCallback.IsSet())
-    {
-        maUserInteractiveChangeCallback.Call(this);
-    }
 }
 
 IMPL_LINK_NOARG(SvxLightCtl3D, InternalSelectionChange, Svx3DLightControl*, void)
diff --git a/svx/source/dialog/rlrcitem.cxx b/svx/source/dialog/rlrcitem.cxx
index 49284af8a9fa..ae962efdf4bc 100644
--- a/svx/source/dialog/rlrcitem.cxx
+++ b/svx/source/dialog/rlrcitem.cxx
@@ -132,7 +132,7 @@ void SvxRulerItem::StateChanged( sal_uInt16 nSID, SfxItemState eState,
         {
             const SvxLRSpaceItem *pItem = dynamic_cast<const SvxLRSpaceItem*>( pState );
             SAL_WARN_IF(pState != nullptr && pItem == nullptr, "svx.dialog", "SvxLRSpaceItem expected");
-            rRuler.UpdateParaBorder(pItem);
+            rRuler.UpdateParaBorder();
         }
         break;
         case SID_RULER_TEXT_RIGHT_TO_LEFT :
diff --git a/svx/source/dialog/svxruler.cxx b/svx/source/dialog/svxruler.cxx
index 8b0123c039cf..29cd1ee88901 100644
--- a/svx/source/dialog/svxruler.cxx
+++ b/svx/source/dialog/svxruler.cxx
@@ -947,15 +947,11 @@ void SvxRuler::UpdatePara(const SvxLRSpaceItem *pItem) // new value of paragraph
     }
 }
 
-void SvxRuler::UpdateParaBorder(const SvxLRSpaceItem * pItem )
+void SvxRuler::UpdateParaBorder()
 {
     /* Border distance */
     if(bActive)
     {
-        if(pItem)
-            mxParaBorderItem.reset(new SvxLRSpaceItem(*pItem));
-        else
-            mxParaBorderItem.reset();
         StartListening_Impl();
     }
 }


More information about the Libreoffice-commits mailing list
diff --git a/compilerplugins/clang/unusedfields.cxx b/compilerplugins/clang/unusedfields.cxx
index a0796fe95547..f08cc843788b 100644
--- a/compilerplugins/clang/unusedfields.cxx
+++ b/compilerplugins/clang/unusedfields.cxx
@@ -607,9 +607,45 @@ void UnusedFields::checkIfReadFrom(const FieldDecl* fieldDecl, const Expr* membe
                 break;
             }
         }
+        else if (auto cxxMemberCallExpr = dyn_cast<CXXMemberCallExpr>(parent))
+        {
+            bool bWriteOnlyCall = false;
+            const CXXMethodDecl * callee = cxxMemberCallExpr->getMethodDecl();
+            if (callee)
+            {
+                const Expr* tmp = dyn_cast<Expr>(child);
+                if (tmp->isBoundMemberFunction(compiler.getASTContext())) {
+                    tmp = dyn_cast<MemberExpr>(tmp)->getBase();
+                }
+                if (cxxMemberCallExpr->getImplicitObjectArgument() == tmp)
+                {
+                    // FIXME perhaps a better solution here would be some kind of SAL_PARAM_WRITEONLY attribute
+                    // which we could scatter around.
+                    std::string name = callee->getNameAsString();
+                    std::transform(name.begin(), name.end(), name.begin(), easytolower);
+                    if (startswith(name, "emplace") || name == "insert"
+                        || name == "erase" || name == "remove" || name == "remove_if" || name == "sort"
+                        || name == "push_back" || name == "pop_back"
+                        || name == "push_front" || name == "pop_front"
+                        || name == "reserve"  || name == "resize" || name == "reset"
+                        || name == "clear" || name == "fill")
+                        // write-only modifications to collections
+                        bWriteOnlyCall = true;
+                    else if (name == "dispose" || name == "disposeAndClear" || name == "swap")
+                        // we're abusing the write-only analysis here to look for fields which don't have anything useful
+                        // being done to them, so we're ignoring things like std::vector::clear, std::vector::swap,
+                        // and VclPtr::disposeAndClear
+                        bWriteOnlyCall = true;
+                }
+            }
+            if (!bWriteOnlyCall)
+                bPotentiallyReadFrom = true;
+            break;
+        }
         else if (auto callExpr = dyn_cast<CallExpr>(parent))
         {
-            // check for calls to ReadXXX() type methods and the operator>>= methods on Any.
+            bool bWriteOnlyCall = false;
+            // check for calls to ReadXXX(foo) type methods, where foo is write-only
             auto callee = getCallee(callExpr);
             if (callee)
             {
@@ -619,24 +655,9 @@ void UnusedFields::checkIfReadFrom(const FieldDecl* fieldDecl, const Expr* membe
                 std::transform(name.begin(), name.end(), name.begin(), easytolower);
                 if (startswith(name, "read"))
                     // this is a write-only call
-                    ;
-                else if (startswith(name, "emplace") || name == "insert"
-                    || name == "erase" || name == "remove" || name == "remove_if" || name == "sort"
-                    || name == "push_back" || name == "pop_back"
-                    || name == "push_front" || name == "pop_front"
-                    || name == "reserve"  || name == "resize"
-                    || name == "clear" || name == "fill")
-                    // write-only modifications to collections
-                    ;
-                else if (name == "dispose" || name == "disposeAndClear" || name == "swap")
-                    // we're abusing the write-only analysis here to look for fields which don't have anything useful
-                    // being done to them, so we're ignoring things like std::vector::clear, std::vector::swap,
-                    // and VclPtr::disposeAndClear
-                    ;
-                else
-                    bPotentiallyReadFrom = true;
+                    bWriteOnlyCall = true;
             }
-            else
+            if (!bWriteOnlyCall)
                 bPotentiallyReadFrom = true;
             break;
         }